@@ -287,6 +287,85 @@ uint32_t dt_tag_get_attached(gint imgid,GList **result)
   return count;
 }
 
+gchar* dt_tag_get_list(gint imgid, const gchar *separator)
+{
+  gchar *result = NULL;
+  GList *taglist = NULL;
+  GList *tags = NULL;
+
+  int count = dt_tag_get_attached (imgid, &taglist);
+
+  if (count < 1)
+    return NULL;
+ 
+  for (int i=0; i < g_list_length(taglist); i++)
+  {
+    dt_tag_t *t;
+    gchar *value = NULL;
+
+    t = g_list_nth_data (taglist, i);
+    value = g_strdup(t->tag);
+
+    gchar **pch;
+    if (g_strrstr(value, "|") && !g_str_has_prefix(value, "darktable|"))
+    {
+      int j = 0;
+
+	    pch = g_strsplit(value, "|", -1);
+      
+      if (pch != NULL)
+      {
+        while (pch[j] != NULL)
+	      {
+          tags = g_list_prepend(tags, g_strdup(pch[j]));
+          j++;
+	      }
+        g_strfreev(pch);
+      }
+	  }
+    else if (!g_str_has_prefix(value, "darktable|"))
+      tags = g_list_prepend(tags, g_strdup(value));
+    g_free (t);
+  }
+
+  g_list_free (taglist);
+
+  result = dt_util_glist_to_str (separator, tags, g_list_length(tags));
+
+  return result;
+}
+
+gchar *dt_tag_get_hierarchical(gint imgid, const gchar *separator)
+{
+  GList *taglist = NULL;
+  GList *tags = NULL;
+  gchar *result = NULL;
+  
+  int count = dt_tag_get_attached (imgid, &taglist);
+
+  if (count < 1)
+    return NULL;
+
+  for (int i=0; i<g_list_length(taglist); i++)
+  {
+    dt_tag_t *t;
+    gchar *value = NULL;
+
+    t = g_list_nth_data (taglist, i);
+    value = g_strdup(t->tag);
+
+    /* return all tags, but omit the internal darktable ones: */
+    if (!g_str_has_prefix(value, "darktable|"))
+      tags = g_list_prepend(tags, value);
+
+    g_free (t);
+  }
+
+  result = dt_util_glist_to_str (separator, tags, g_list_length(tags));
+
+  return result;
+}
+
 uint32_t dt_tag_get_suggestions(const gchar *keyword, GList **result)
 {
   sqlite3_stmt *stmt;
