@@ -24,6 +24,7 @@
 #include "control/control.h"
 #include "gui/accelerators.h"
 #include "gui/gtk.h"
+#include "gui/presets.h"
 #include "develop/imageop.h"
 #include "dtgtk/resetlabel.h"
 
@@ -53,6 +54,26 @@ groups ()
   return IOP_GROUP_COLOR;
 }
 
+void init_presets (dt_iop_module_so_t *self)
+{
+  dt_iop_colorcorrection_params_t p;
+
+  p.hia = -0.95f;
+  p.loa = 3.55f;
+  p.hib = 4.5f;
+  p.lob = 0.0f;
+  p.saturation = 1.0f;
+  dt_gui_presets_add_generic(_("warming filter"), self->op, self->version(), &p, sizeof(p), 1);
+
+  p.hia = 0.95f;
+  p.loa = -3.55f;
+  p.hib = -4.5f;
+  p.lob = -0.0f;
+  p.saturation = 1.0f;
+  dt_gui_presets_add_generic(_("cooling filter"), self->op, self->version(), &p, sizeof(p), 1);
+
+}
+
 void init_key_accels(dt_iop_module_so_t *self)
 {
   dt_accel_register_slider_iop(self, FALSE, NC_("accel", "saturation"));
