@@ -229,6 +229,8 @@ void gui_init(struct dt_iop_module_t *self)
                     G_CALLBACK (dt_iop_levels_motion_notify), self);
   g_signal_connect (G_OBJECT (c->area), "leave-notify-event",
                     G_CALLBACK (dt_iop_levels_leave_notify), self);
+  g_signal_connect (G_OBJECT (c->area), "scroll-event",
+		    G_CALLBACK (dt_iop_levels_scroll), self);
 }
 
 void gui_cleanup(struct dt_iop_module_t *self)
@@ -354,6 +356,64 @@ static gboolean dt_iop_levels_expose(GtkWidget *widget, GdkEventExpose *event, g
   return TRUE;
 }
 
+/**
+ * Move handler_move to new_pos, storing the value in handles,
+ * while keeping new_pos within a valid range
+ * and preserving the ratio between the three handles.
+ *
+ * @param handle_move Handle to move
+ * @param new_pow New position (0..1)
+ * @param levels Pointer to dt_iop_levels_params->levels.
+ * @param drag_start_percentage Ratio between handle 1, 2 and 3.
+ *
+ * @return TRUE if the marker were given a new position. FALSE otherwise.
+ */
+static void dt_iop_levels_move_handle(int handle_move, float new_pos, float *levels, float drag_start_percentage)
+{
+  float min_x = 0;
+  float max_x = 1;
+
+  if ((handle_move < 0) || handle_move > 2)
+    return;
+
+  if (levels == NULL)
+    return;
+
+  // Determining the minimum and maximum bounds for the drag handles
+  switch(handle_move)
+  {
+  case 0:
+    max_x = fminf(levels[2] - (0.05 / drag_start_percentage),
+                  1);
+    max_x = fminf((levels[2] * (1 - drag_start_percentage) - 0.05)
+                  / (1 - drag_start_percentage),
+                  max_x);
+    break;
+
+  case 1:
+    min_x = levels[0] + 0.05;
+    max_x = levels[2] - 0.05;
+    break;
+
+  case 2:
+    min_x = fmaxf((0.05 / drag_start_percentage) + levels[0],
+                  0);
+    min_x = fmaxf((levels[0] * (1 - drag_start_percentage) + 0.05)
+                  / (1 - drag_start_percentage),
+                  min_x);
+    break;
+  }
+
+  levels[handle_move] =
+      fminf(max_x, fmaxf(min_x, new_pos));
+
+  if(handle_move != 1)
+    levels[1] = levels[0] + (drag_start_percentage
+                             * (levels[2] - levels[0]));
+
+}
+
+
 static gboolean dt_iop_levels_motion_notify(GtkWidget *widget, GdkEventMotion *event, gpointer user_data)
 {
   dt_iop_module_t *self = (dt_iop_module_t *)user_data;
@@ -375,40 +435,7 @@ static gboolean dt_iop_levels_motion_notify(GtkWidget *widget, GdkEventMotion *e
     {
       const float mx = (CLAMP(event->x - inset, 0, width)) / (float)width;
 
-      float min_x = 0;
-      float max_x = 1;
-
-      // Determining the minimum and maximum bounds for the drag handles
-      switch(c->handle_move)
-      {
-      case 0:
-        max_x = fminf(p->levels[2] - (0.05 / c->drag_start_percentage),
-                      1);
-        max_x = fminf((p->levels[2] * (1 - c->drag_start_percentage) - 0.05)
-                      / (1 - c->drag_start_percentage),
-                      max_x);
-        break;
-
-      case 1:
-        min_x = p->levels[0] + 0.05;
-        max_x = p->levels[2] - 0.05;
-        break;
-
-      case 2:
-        min_x = fmaxf((0.05 / c->drag_start_percentage) + p->levels[0],
-                      0);
-        min_x = fmaxf((p->levels[0] * (1 - c->drag_start_percentage) + 0.05)
-                      / (1 - c->drag_start_percentage),
-                      min_x);
-        break;
-      }
-
-      p->levels[c->handle_move] =
-          fminf(max_x, fmaxf(min_x, mx));
-
-      if(c->handle_move != 1)
-        p->levels[1] = p->levels[0] + (c->drag_start_percentage
-                                       * (p->levels[2] - p->levels[0]));
+      dt_iop_levels_move_handle(c->handle_move, mx, p->levels, c->drag_start_percentage);
     }
     dt_dev_add_history_item(darktable.develop, self, TRUE);
   }
@@ -440,8 +467,22 @@ static gboolean dt_iop_levels_button_press(GtkWidget *widget, GdkEventButton *ev
   if(event->button == 1)
   {
     dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-    dt_iop_levels_gui_data_t *c = (dt_iop_levels_gui_data_t *)self->gui_data;
-    c->dragging = 1;
+
+    if(event->type == GDK_2BUTTON_PRESS) {
+      // Reset
+      dt_iop_levels_gui_data_t *c = (dt_iop_levels_gui_data_t *)self->gui_data;
+      memcpy(self->params, self->default_params, self->params_size);
+
+      // Needed in case the user scrolls or drags immediately after a reset,
+      // as drag_start_percentage is only updated when the mouse is moved.
+      c->drag_start_percentage = 0.5;
+
+      dt_dev_add_history_item(darktable.develop, self, TRUE);
+      gtk_widget_queue_draw(self->widget);
+    } else {
+      dt_iop_levels_gui_data_t *c = (dt_iop_levels_gui_data_t *)self->gui_data;
+      c->dragging = 1;
+    }
     return TRUE;
   }
   return FALSE;
@@ -459,3 +500,37 @@ static gboolean dt_iop_levels_button_release(GtkWidget *widget, GdkEventButton *
   return FALSE;
 }
 
+static gboolean dt_iop_levels_scroll(GtkWidget *widget, GdkEventScroll *event, gpointer user_data)
+{
+  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
+  dt_iop_levels_gui_data_t *c = (dt_iop_levels_gui_data_t *)self->gui_data;
+  dt_iop_levels_params_t *p = (dt_iop_levels_params_t *)self->params;
+
+  const float interval = 0.002; // Distance moved for each scroll event
+  gboolean updated = FALSE;
+  float new_position = 0;
+
+  if (c->dragging) {
+    return FALSE;
+  }
+
+  if(event->direction == GDK_SCROLL_UP)
+  {
+    new_position = p->levels[c->handle_move] + interval;
+    updated = TRUE;
+  }
+  else if(event->direction == GDK_SCROLL_DOWN)
+  {
+    new_position = p->levels[c->handle_move] - interval;
+    updated = TRUE;
+  }
+
+  if (updated) {
+    dt_iop_levels_move_handle(c->handle_move, new_position,
+		              p->levels, c->drag_start_percentage);
+    dt_dev_add_history_item(darktable.develop, self, TRUE);
+    return TRUE;
+  }
+
+  return FALSE;
+}
