@@ -115,15 +115,17 @@ void process (struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, void
     if(inp[0] >= upper || inp[1] >= upper || inp[2] >= upper)
     {
 // 			mask[y*stride+x] = 255;
-      outp[0] = 1;
+//    black:
+      outp[0] = 0;
       outp[1] = 0;
       outp[2] = 0;
     }
     else if(inp[0] <= lower && inp[1] <= lower && inp[2] <= lower)
     {
 // 			mask[(y*stride+x)+(stride*roi_out->height)] = 255;
-      outp[0] = 0;
-      outp[1] = 0;
+//    white:
+      outp[0] = 1;
+      outp[1] = 1;
       outp[2] = 1;
     }
     else
@@ -299,7 +301,7 @@ void gui_init(struct dt_iop_module_t *self)
   g_signal_connect (G_OBJECT (g->upper), "value-changed", G_CALLBACK (upper_callback), self);
 
   /* add quicktool button for enable/disable the plugin */
-  GtkWidget *button = dtgtk_button_new(dtgtk_cairo_paint_overexposed, CPF_STYLE_FLAT|CPF_DO_NOT_USE_BORDER);
+  GtkWidget *button = dtgtk_togglebutton_new(dtgtk_cairo_paint_overexposed, CPF_STYLE_FLAT|CPF_DO_NOT_USE_BORDER);
   g_object_set(G_OBJECT(button), "tooltip-text", _("toggle over/under exposed indication"),
                (char *)NULL);
   g_signal_connect (G_OBJECT (button), "clicked",
