@@ -195,6 +195,29 @@ static gchar * _watermark_get_svgdoc( dt_iop_module_t *self, dt_iop_watermark_da
   else return NULL;
 
   gchar *svgdata=NULL;
+  char datetime[200];
+
+  // EXIF datetime
+  struct tm tt_exif = {0};
+  if(sscanf(image->exif_datetime_taken,"%d:%d:%d %d:%d:%d",
+              &tt_exif.tm_year,
+              &tt_exif.tm_mon,
+              &tt_exif.tm_mday,
+              &tt_exif.tm_hour,
+              &tt_exif.tm_min,
+              &tt_exif.tm_sec
+             ) == 6
+     )
+  {
+    tt_exif.tm_year-=1900;
+    tt_exif.tm_mon--;
+  }
+
+  // Current datetime
+  struct tm tt_cur = {0};
+  time_t t = time(NULL);
+  (void)localtime_r(&t, &tt_cur);
+
   if( g_file_get_contents( filename, &svgdata, &length, NULL) )
   {
     // File is loaded lets substitute strings if found...
@@ -233,12 +256,184 @@ static gchar * _watermark_get_svgdoc( dt_iop_module_t *self, dt_iop_watermark_da
     }
 
     // Image exif
+    // EXIF date
     svgdoc = _string_substitute(svgdata,"$(EXIF.DATE)",image->exif_datetime_taken);
     if( svgdoc != svgdata )
     {
       g_free(svgdata);
       svgdata = svgdoc;
     }
+    // $(EXIF.DATE.SECOND) -- 00..60
+    strftime(datetime, sizeof(datetime), "%S", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.SECOND)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.MINUTE) -- 00..59
+    strftime(datetime, sizeof(datetime), "%M", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.MINUTE)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.HOUR) -- 00..23
+    strftime(datetime, sizeof(datetime), "%H", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.HOUR)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.HOUR_AMPM) -- 01..12
+    strftime(datetime, sizeof(datetime), "%I %p", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.HOUR_AMPM)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.DAY) -- 01..31
+    strftime(datetime, sizeof(datetime), "%d", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.DAY)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.MONTH) -- 01..12
+    strftime(datetime, sizeof(datetime), "%m", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.MONTH)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.SHORT_MONTH) -- Jan, Feb, .., Dec, localized
+    strftime(datetime, sizeof(datetime), "%b", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.SHORT_MONTH)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.LONG_MONTH) -- January, February, .., December, localized
+    strftime(datetime, sizeof(datetime), "%B", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.LONG_MONTH)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.SHORT_YEAR) -- 12
+    strftime(datetime, sizeof(datetime), "%y", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.SHORT_YEAR)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(EXIF.DATE.LONG_YEAR) -- 2012
+    strftime(datetime, sizeof(datetime), "%Y", &tt_exif);
+    svgdoc = _string_substitute(svgdata,"$(EXIF.DATE.LONG_YEAR)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+
+    // Current date
+    // $(DATE) -- YYYY:
+    dt_gettime_t(datetime, t);
+    svgdoc = _string_substitute(svgdata,"$(DATE)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.SECOND) -- 00..60
+    strftime(datetime, sizeof(datetime), "%S", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.SECOND)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.MINUTE) -- 00..59
+    strftime(datetime, sizeof(datetime), "%M", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.MINUTE)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.HOUR) -- 00..23
+    strftime(datetime, sizeof(datetime), "%H", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.HOUR)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.HOUR_AMPM) -- 01..12
+    strftime(datetime, sizeof(datetime), "%I %p", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.HOUR_AMPM)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.DAY) -- 01..31
+    strftime(datetime, sizeof(datetime), "%d", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.DAY)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.MONTH) -- 01..12
+    strftime(datetime, sizeof(datetime), "%m", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.MONTH)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.SHORT_MONTH) -- Jan, Feb, .., Dec, localized
+    strftime(datetime, sizeof(datetime), "%b", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.SHORT_MONTH)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.LONG_MONTH) -- January, February, .., December, localized
+    strftime(datetime, sizeof(datetime), "%B", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.LONG_MONTH)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.SHORT_YEAR) -- 12
+    strftime(datetime, sizeof(datetime), "%y", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.SHORT_YEAR)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+    // $(DATE.LONG_YEAR) -- 2012
+    strftime(datetime, sizeof(datetime), "%Y", &tt_cur);
+    svgdoc = _string_substitute(svgdata,"$(DATE.LONG_YEAR)",datetime);
+    if( svgdoc != svgdata )
+    {
+      g_free(svgdata);
+      svgdata = svgdoc;
+    }
+
     svgdoc = _string_substitute(svgdata,"$(EXIF.MAKER)",image->exif_maker);
     if( svgdoc != svgdata )
     {
